.. _reporting-bugs:

*********************************
Reporting Bugs in ulif.openoffice
*********************************

The developers would like to know of any deficiencies you find in
`ulif.openoffice`.

Also telling about errors and shortcomings in the documentation are
welcome. Please write to ``uli at gnufix dot de`` if you find any.

.. seealso::

   `How to Report Bugs Effectively
   <http://www.chiark.greenend.org.uk/~sgtatham/bugs.html>`_ Article
   which goes into some detail about how to create a useful bug
   report. This describes what kind of information is useful and why
   it is useful.

   `Bug Writing Guidelines
   <http://www.mozilla.org/quality/bug-writing-guidelines.html>`_
   Information about writing a good bug report.  Some of this is
   specific to the Mozilla project, but describes general good
   practices.
